# nekore

Nekore is a library that can be used to create utility bills for apartment buildings. Nekore is being developed against the background of German regulations. It is therefore probably only of limited use for other countries.

The [example](./example/) shows how nekore can be used in your own scripts.
